@@ -5,28 +5,11 @@ package API::Instagram::Media::Comment;
 use Moo;
 use Time::Moment;
 
-has _api         => ( is => 'ro', required => 1 );
 has id           => ( is => 'ro', required => 1 );
-has from         => ( is => 'ro', required => 1, coerce => \&_coerce_from );
+has from         => ( is => 'ro', required => 1, coerce => sub { API::Instagram->instance->user( $_[0] ) } );
 has text         => ( is => 'ro', required => 1 );
 has created_time => ( is => 'ro', coerce => sub { Time::Moment->from_epoch( $_[0] ) } );
 
-sub BUILDARGS {
-	my $self = shift;
-	my $opts = shift;
-	$opts->{from} = [ $opts->{_api}, $opts->{from} ];
-	return $opts;
-}
-
-############################################################
-# Attributes coercion that API::Instagram object reference #
-############################################################
-sub _coerce_from {
-	my ( $self, $data ) = @{$_[0]};
-	return unless defined $data;
-	$self->user( $data );
-};
-
 
 1;
 
@@ -40,11 +23,9 @@ __END__
 
 API::Instagram::Media::Comment - Instagram Media Comment Object
 
-=for Pod::Coverage BUILDARGS
-
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
